@@ -10,8 +10,11 @@ pub use parse_tree::ParseTree;
 pub use parse_tree::RawColumn;
 pub use parse_tree::RawCreateTableCommand;
 pub use parse_tree::RawInsertCommand;
+pub use parse_tree::RawSelectCommand;
 
 mod planned_statement;
+pub use planned_statement::CartesianJoin;
+pub use planned_statement::FullTableScan;
 pub use planned_statement::ModifyTablePlan;
 pub use planned_statement::Plan;
 pub use planned_statement::PlannedCommon;
@@ -27,3 +30,4 @@ pub use query_tree::TargetEntry;
 
 mod sql_tuple;
 pub use sql_tuple::SqlTuple;
+pub use sql_tuple::SqlTupleError;
