@@ -3,15 +3,18 @@
 mod common;
 mod create;
 mod insert;
+mod select;
+
+use self::select::parse_select;
 
 use super::objects::ParseTree;
 use create::parse_create_table;
 use insert::parse_insert;
 use nom::branch::alt;
-use nom::combinator::{all_consuming, complete, cut};
+use nom::combinator::{all_consuming, complete};
 use nom::error::{convert_error, ContextError, ParseError, VerboseError};
+use nom::Finish;
 use nom::IResult;
-use nom::{Err, Finish};
 use thiserror::Error;
 
 pub struct SqlParser {}
@@ -27,7 +30,11 @@ impl SqlParser {
     fn nom_parse<'a, E: ParseError<&'a str> + ContextError<&'a str>>(
         input: &'a str,
     ) -> IResult<&'a str, ParseTree, E> {
-        complete(all_consuming(alt((parse_create_table, parse_insert))))(input)
+        complete(all_consuming(alt((
+            parse_create_table,
+            parse_insert,
+            parse_select,
+        ))))(input)
     }
 }
 
