@@ -2,7 +2,7 @@ mod common;
 
 #[test]
 fn simple_insert() -> Result<(), Box<dyn std::error::Error>> {
-    let (mut tm, mut engine) = common::create_engine();
+    let (mut tm, mut engine) = common::_create_engine();
 
     let create_test =
         "create table foo (bar text, baz text not null, another text null)".to_string();
